@@ -174,3 +174,19 @@ class FormaPagamentoConfiguracao(models.Model):
 
     def __unicode__(self):
         return unicode(self.id)
+
+
+class Envio(models.Model):
+    """Formas de envios."""
+    id = models.AutoField(db_column="envio_id", primary_key=True)
+    nome = models.CharField(db_column="envio_nome", max_length=128)
+    codigo = models.CharField(db_column="envio_codigo", max_length=128)
+
+    class Meta:
+        app_label = "configuracao"
+        db_table = u"configuracao\".\"tb_envio"
+        ordering = ["posicao", "nome"]
+        unique_together = (("nome", "codigo", "conta"),)
+
+    def __unicode__(self):
+        return self.nome
