@@ -93,7 +93,7 @@ class Fatura(models.Model):
     cartao_de_credito_cv = models.CharField(db_column="fatura_cartao_de_credito_cv")
     cartao_de_credito_numero = models.CharField(db_column="fatura_cartao_de_credito_numero")
     controle_lancamento_numero = models.IntegerField(db_column="fatura_controle_lancamento_numero", default=None)
-    controle_quitada = models.IntegerField(db_column="fatura_controle_quitada", default=None)
+    controle_lancamento_quitado = models.BooleanField(db_column="fatura_controle_lancamento_quitado", default=False)
     controle_nota_fiscal = models.IntegerField(db_column="fatura_controle_nota_fiscal", default=None)
     json = JSONField(db_column='fatura_json', null=True, default=None)
     observacao = models.TextField(db_column="fatura_observacao")
@@ -112,15 +112,15 @@ class FaturaItem(models.Model):
     id = models.AutoField(db_column="fatura_item_id", primary_key=True)
     valor_cheio = models.DecimalField(db_column="fatura_item_valor_cheio", decimal_places=2, max_digits=12)
     valor_cobrado = models.DecimalField(db_column="fatura_item_valor_cobrado", decimal_places=2, max_digits=12)
-    referencia_tabela = models.CharField(db_column="fatura_item_referencia_tabela")
-    referencia_campo = models.CharField(db_column="fatura_item_referencia_campo")
-    referencia_id = models.IntegerField(db_column="fatura_item_referencia_id")
-    referencia_situacao_principal = models.CharField(db_column="fatura_item_referencia_situacao_principal")
-    referencia_situacao_complementar = models.CharField(db_column="fatura_item_referencia_situacao_complementar")
+    referencia_tabela = models.CharField(db_column="fatura_item_referencia_tabela", null=True, default=None)
+    referencia_campo = models.CharField(db_column="fatura_item_referencia_campo", null=True, default=None)
+    referencia_id = models.IntegerField(db_column="fatura_item_referencia_id", null=True, default=None)
+    referencia_situacao_principal = models.CharField(db_column="fatura_item_referencia_situacao_principal", null=True, default=None)
+    referencia_situacao_complementar = models.CharField(db_column="fatura_item_referencia_situacao_complementar", null=True, default=None)
     json = JSONField(db_column='fatura_item_json', null=True, default=None)
 
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
-    fatura = models.ForeignKey("Fatura", db_column="fatura_id")
+    fatura = models.ForeignKey("Fatura", db_column="fatura_id", related_name='itens')
 
     class Meta:
         db_table = u"faturamento\".\"tb_fatura_item"
@@ -164,7 +164,6 @@ class PlanoAssinatura(models.Model):
     ciclo_fim = models.DateField(db_column="plano_assinatura_ciclo_fim")
     controle_trafego = models.IntegerField(db_column="plano_assinatura_controle_trafego", default=0)
     controle_visitas = models.IntegerField(db_column="plano_assinatura_controle_visitas", default=0)
-    controle_produtos = models.IntegerField(db_column="plano_assinatura_controle_produtos", default=0)
     data_criacao = models.DateTimeField(db_column="plano_assinatura_data_criacao", auto_now_add=True)
     data_modificacao = models.DateTimeField(db_column="plano_assinatura_data_modificacao", auto_now=True)
 
