@@ -8,12 +8,30 @@ class Contrato(models.Model):
 
     id = models.AutoField(db_column="contrato_id", primary_key=True)
     nome = models.CharField(db_column="contrato_nome", max_length=255)
+    ativo = models.BooleanField(db_column="contrato_ativo", default=True)
     codigo = models.CharField(db_column="contrato_codigo", max_length=255, unique=True)
     dominio = models.CharField(db_column="contrato_dominio", max_length=255)
     url_institucional = models.CharField(db_column="contrato_url_institucional", max_length=255)
-    parametros = JSONField(u'Parametros do contrato', db_column="contrato_parametros", null=True, help_text=u'Os parametros informados vão sobreescrever os do contrato principal.')
+    parametros = JSONField(u'Parametros do contrato', db_column="contrato_parametros", null=True)
     tipo = models.CharField(db_column="contrato_tipo", max_length=32)
 
+    razao_social = models.CharField(db_column="contrato_razao_social", max_length=255)
+    tipo_pessoa = models.CharField(db_column="contrato_tipo_pessoa", max_length=2, null=True, default='PJ')
+    cpf_cnpj = models.CharField(db_column="contrato_cpf_cnpj", max_length=15, null=True, default=None)
+    nome_responsavel = models.CharField(db_column="contrato_nome_responsavel", max_length=128, null=True, default=None)
+    email_nota_fiscal = models.CharField(db_column="contrato_email_nota_fiscal", max_length=128, null=True, default=None)
+    telefone_principal = models.CharField(db_column="contrato_telefone_principal", max_length=11, null=True, default=None)
+    telefone_celular = models.CharField(db_column="contrato_telefone_celular", max_length=11, null=True, default=None)
+    endereco_logradouro = models.CharField(db_column="contrato_endereco_logradouro", max_length=128, null=True, default=None)
+    endereco_numero = models.CharField(db_column="contrato_endereco_numero", max_length=32, null=True, default=None)
+    endereco_complemento = models.CharField(db_column="contrato_endereco_complemento", max_length=128, null=True, default=None)
+    endereco_bairro = models.CharField(db_column="contrato_endereco_bairro", max_length=50, null=True, default=None)
+    endereco_cep = models.CharField(db_column="contrato_endereco_cep", max_length=8, null=True, default=None)
+    endereco_cidade_ibge = models.IntegerField(db_column="contrato_endereco_cidade_ibge", null=True, default=None)
+    endereco_estado = models.CharField(u'Estado', db_column="contrato_endereco_estado", max_length=2, null=True, default=None)
+
+    colecao = models.ForeignKey('faturamento.Colecao', db_column="colecao_id")
+
     class Meta:
         app_label = 'plataforma'
         db_table = u"plataforma\".\"tb_contrato"
@@ -21,10 +39,22 @@ class Contrato(models.Model):
 
 class Conta(models.Model):
 
+    CONTA_SITUACOES = [
+        ('ATIVA','Loja ATIVA'),
+        ('BLOQUEADA','Loja BLOQUEADA'),
+        ('CANCELADA','Loja CANCELADA')
+    ]
+
     id = models.AutoField(db_column="conta_id", primary_key=True)
     apelido = models.CharField(db_column="conta_apelido", max_length=32)
     nome = models.CharField(db_column="conta_loja_nome", max_length=128, null=False)
+    email = models.CharField(db_column="conta_loja_email", max_length=128, null=True, default=None)
     dominio = models.CharField(db_column="conta_loja_dominio", max_length=128, null=True, default=None)
+    situacao = models.CharField(db_column="conta_situacao", max_length=32, null=False, default='ATIVA', choices=CONTA_SITUACOES)
+
+    habilitar_facebook = models.BooleanField(db_column='conta_habilitar_facebook', default=False)
+    habilitar_mercadolivre = models.BooleanField(db_column='conta_habilitar_mercadolivre', default=False)
+    habilitar_mobile = models.BooleanField(db_column='conta_habilitar_mobile', default=True)
 
     contrato = models.ForeignKey('Contrato', db_column="contrato_id")
     plano = models.ForeignKey('faturamento.Plano', db_column="plano_id")
@@ -33,6 +63,30 @@ class Conta(models.Model):
         app_label = 'plataforma'
         db_table = u"plataforma\".\"tb_conta"
 
+    @property
+    def url_dominio(self):
+        if self.dominio:
+            return self.dominio
+        else:
+            return self.url_subdominio
+
+    @property
+    def url_subdominio_facebook(self):
+        return "%s-facebook.%s" % (self.apelido, self.contrato.dominio)
+
+    @property
+    def url_subdominio(self):
+        return "%s.%s" % (self.apelido, self.contrato.dominio)
+
+    @property
+    def email_contato(self):
+        if self.email:
+            return self.email
+        elif len(self.usuarios.all()):
+            return self.usuarios.all()[0].email
+        else:
+            return None
+
 
 class Dominio(models.Model):
     """Lista de domínios habilitados para uma conta."""
